#
# spec file for package python-pyroute2
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-pyroute2
Version:        0.7.12
Release:        1.4
Summary:        Python Netlink library
License:        Apache-2.0 OR GPL-2.0-or-later
URL:            https://github.com/svinota/pyroute2
Source:         https://files.pythonhosted.org/packages/source/p/pyroute2/pyroute2-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
Provides:       python-pyroute2.core = %{version}
Obsoletes:      python-pyroute2.core < %{version}
Provides:       python-pyroute2.ethtool = %{version}
Obsoletes:      python-pyroute2.ethtool < %{version}
Provides:       python-pyroute2.ipdb = %{version}
Obsoletes:      python-pyroute2.ipdb < %{version}
Provides:       python-pyroute2.ipset = %{version}
Obsoletes:      python-pyroute2.ipset < %{version}
Provides:       python-pyroute2.ndb = %{version}
Obsoletes:      python-pyroute2.ndb < %{version}
Provides:       python-pyroute2.nftables = %{version}
Obsoletes:      python-pyroute2.nftables < %{version}
Provides:       python-pyroute2.nslink = %{version}
Obsoletes:      python-pyroute2.nslink < %{version}
%python_subpackages

%description
Pyroute2 is a pure Python netlink library. It requires only Python stdlib, no
3rd party libraries. The library was started as an RTNL protocol
implementation, so the name is pyroute2, but now it supports many netlink
protocols. Some supported netlink families and protocols:

  * rtnl, network settings --- addresses, routes, traffic controls
  * nfnetlink --- netfilter API: ipset, nftables, ...
  * ipq --- simplest userspace packet filtering, iptables QUEUE target
  * devlink --- manage and monitor devlink-enabled hardware
  * generic --- generic netlink families
  * nl80211 --- wireless functions API (basic support)
  * taskstats --- extended process statistics
  * acpi_events --- ACPI events monitoring
  * thermal_events --- thermal events monitoring
  * VFS_DQUOT --- disk quota events monitoring

%prep
%setup -q -n pyroute2-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%python_clone -a %{buildroot}%{_bindir}/pyroute2-cli
%python_clone -a %{buildroot}%{_bindir}/pyroute2-dhcp-client
%python_clone -a %{buildroot}%{_bindir}/pyroute2-test-platform
%python_clone -a %{buildroot}%{_bindir}/ss2

%files %{python_files}
%doc README.rst CHANGELOG.rst
%license LICENSE LICENSE.Apache-2.0 LICENSE.GPL-2.0-or-later
%python_alternative %{_bindir}/pyroute2-cli
%python_alternative %{_bindir}/pyroute2-dhcp-client
%python_alternative %{_bindir}/pyroute2-test-platform
%python_alternative %{_bindir}/ss2
%{python_sitelib}/*

%changelog
* Fri Mar  1 2024 Dirk Müller <dmueller@suse.com>
- update to 0.7.12:
  * cli: move readline import to the script
  * nl80211: decoder improvements
  * remote: fix dump() on RemoteIPRoute
  * ndb: add ensure() call
  * ethtool: ring support
    ndb: fix sources objects counting
  * ethtool: ring support
  * ndb: fix FDB records index
  * ndb: fix sources objects counting
* Thu Dec 14 2023 Dirk Müller <dmueller@suse.com>
- update to 0.7.10:
  * ss2: fix classful flow data
  * ci: add Python versions 3.8 and 3.12, update platform
    versions
  * l2tp: fix get_tunnel/get_session
  * ndb: compat fix
  * ndb: recordset pipes
  * netns: RISCV64 fix
  * netns: loongarch support
  * ethtool: statistics support
  * ethtool: dynamic ioctl gstrings
  * NetNS: set_netnsid fix
  * iproute: nsid allocation
  * iproute: dump mpls routes
  * rtnl: CAN support
  * minimal: fix for embedded envs
  * diag: support CGROUP_ID
  * iwutil: get/set interface (by ifindex) type
  * tc: 'duplicate' parameter fix
  * ss2: more fixes
  * ss2: user context patch
  * ndb: basic altname support
  * nl80211: decoder improvements
  * setup: static loader
  * iproute: support altname in link_lookup()
  * ethtool: fd leaks
  * nlsocket: fix marshal reference
  * rtnl: SRv6 updates
  * connector: basic implementation
  * nftables: sets draft
  * ss2: provide as a module
* Sat Oct  1 2022 Dirk Müller <dmueller@suse.com>
- update to 0.7.3:
  * nlsocket: CompileContext support
  * nlsocket: support for per request parsers (see IPRoute.get_default_routes())
  * generic: added support for dumping policies <#981>
  * ndb: changed API for reports
  * conntrack: fix TCP states <#991>
  * ipmock: new component (IPMock) for mock tests
  * thermal: update
  * ci: nlm_generator = True -- force using generators in the CI
  * iproute: fix neighbours dump <#962>
  * iproute: fix rule add <#964>
  * setup: fix build-backend <#961>
  * packaging: back to single package layout <#935>
  * packaging: static version <#939>
  * ci: use nox, finish migration from nose
  * netlink: universal nlmsg.get()
* Wed Jul  6 2022 Dirk Müller <dmueller@suse.com>
- update to 0.6.13:
  * requests: IPv6 routes default priority
  * requests: fix wrong family on empty IP targets
  * ndb: fix NetlinkError escalation routine on apply
* Wed Jun 22 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- update to 0.6.12:
  * ndb: allow dict as keys in __contains__
  * ndb: fixed count() on nested views
  * ndb: fix IPv6 addr removal: #926
  * ifinfmsg: fixed IFLA_IPTUN_FLAGS: #924
  * tc: fix tcm_info setting: #928
- update to 0.6.11:
  * ipdb: fix requests compatibility: #920
  * ipdb: added deprecation warning
- update to 0.6.10:
  * ndb: fix DB reload on incomplete requests in the IPRoute API fallbacks: #890
  * ndb: basic ipvlan support
  * ndb: support ndb.schema.backup("filename") fro SQLite3 backend
  * ndb: transactions, CheckProcess, PingAddress, see test_ndb/test_transaction.py and docs
  * ndb: make snapshots only for commit() calls, no automatic snapshots for apply()
  * netlink: filter out all the subsequent messages starting from the first error: #892
  * protocols: fix arp module export
  * iproute: deprecate positional arguments to IPRoute.rule()
  * iproute, ndb: use pyroute2.requests to filter and transform API call arguments
  * conntrack: fix exports: #900
  * nftables: multiple fixes: #902
  * tc: fix em_ipset crash: #905
  * tests: integrated pre-commit, github actions and more
  * tests: support basic OpenBSD tests
  * pyroute2-cli: parser fixes
* Tue May 10 2022 Dirk Müller <dmueller@suse.com>
- update to 0.6.9:
  * wireguard peer fix for both IPv4 and IPv6:
  * netns: avoid extra libc reloads:
  * wireguard: IPv6 fixes:
  * ndb: support arbitrary IPRoute-compatible source classes
  * ndb: tolerate source failures
  * ndb: chaotic tests
  * general: kernel version parser:
  * package: static version file:
  * iproute: support custom link kind classes:
  * ndb: reload of tunnels in the down state
  * ndb: improved reliability in the state sync, affected multihop and encap routes
  * ndb: improved neighbours management
  * tuntap: support loongarch
  * ndb: fix routes cleanup
  * ndb: support `in` for sources, interfaces and addresses
  * ndb: support changing tunnel (gre, ipip, ...) attributes
  * netlink: support NLM_F_DUMP_INTR
* Sat Oct 16 2021 Dirk Müller <dmueller@suse.com>
- update to 0.6.5:
  * ndb: fix `in` for sources
  * core: provide entry_points aliases for legacy code
  * packaging: fix missing exports
  * ndb: memory leak fix
  * packaging: fix internal modules import
  * netlink: DEFAULT_RCVBUF size increased
  * rtnl: fix COLLECT_METADATA for geneve devices
  * ndb: route spec fixes
  * packaging: force virtual packages to require same versions
  * core: relocate RemoteIPRoute
  * wireguard: fix key parsing
  * packaging: fix importlib-metadata deps
  * tc: support pfifo qdisc
  * packaging: new layout
  * ndb: fix default routes keys
  * mptcp: basic support
  * netlink: ext_ack support fix
  * tc: netem rate setting
  * NSPopen: fix fd leak
* Fri Apr 30 2021 Antonio Larrosa <alarrosa@suse.com>
- update to 0.5.18:
  * netlink: support zero length lladdr
    <https://github.com/svinota/pyroute2/issues/717>
- update to 0.5.17:
  * license: aligned cli/ss2
    <https://github.com/svinota/pyroute2/pull/777>
  * ndb: del_ip() improvements
  * ndb: wait(timeout=...)
- update to 0.5.16:
  * ndb: fix syntax for Python < 3.6
    <https://github.com/svinota/pyroute2/pull/776>
- update to 0.5.15:
  * ndb: don't mess with SQL adapters unless really needed
  * ndb: support more virtual interface types
  * ndb: support in for views and record sets
  * ndb: fix nested fetches from DB
  * tests: start migration to pytest
* Wed Sep 16 2020 Dirk Mueller <dmueller@suse.com>
- update to 0.5.14:
  * iproute: ip neigh get <https://github.com/svinota/pyroute2/pull/723>
  * iproute: link_lookup fix <https://github.com/svinota/pyroute2/pull/725>
  * nftables: missing hooks <https://github.com/svinota/pyroute2/pull/732>
  * netns: fix <https://github.com/svinota/pyroute2/pull/733>
* Tue Aug  4 2020 Dirk Mueller <dmueller@suse.com>
- update to 0.5.13:
  * netns: allow to pass custom libc reference <https://github.com/svinota/pyroute2/issues/702>
  * generic: att L2TP support <https://github.com/svinota/pyroute2/pull/709>
  * iproute: link_lookup() optimization <https://github.com/svinota/pyroute2/issues/712>
  * ndb: basic cluster support
* Thu Jul  2 2020 pgajdos@suse.com
- test package with pytest, drop unused nose dependency
* Tue Jun  2 2020 Dirk Mueller <dmueller@suse.com>
- update to 0.5.12:
  * rtnl: implement team config pass <https://github.com/svinota/pyroute2/issues/699>
  * ndb.auth: example auth modules for RADIUS and OpenStack / Keystone
  * cli: syntax fixes
* Wed May 20 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Wed Apr 29 2020 Dirk Mueller <dmueller@suse.com>
- update to 0.5.11:
  * ndb.report: filters and transformations
  * ndb.objects.route: support basic MPLS routes management
  * ndb.objects.route: support MPLS lwtunnel routes
  * ndb.schema: reschedule events
* Sat Mar 14 2020 Dirk Mueller <dmueller@suse.com>
- update to 0.5.10 bsc#1161898:
  * general: don't use pkg_resources <https://github.com/svinota/pyroute2/issues/677>
  * iproute: fix Windows support
  * netlink: provide the target field
  * ndb: use the target field from the netlink header
  * ndb: multiple SQL fixes, transactions fixed with the PostgreSQL backend
  * ndb: multiple object cache fixes <https://github.com/svinota/pyroute2/issues/683>
  * ndb.schema: drop DB triggers
  * ndb.objects: fix object management within a netns <https://github.com/svinota/pyroute2/issues/628>
  * ndb.objects.route: support route metrics
  * ndb.objects.route: fix default route syntax
* Fri Feb 28 2020 Dirk Mueller <dmueller@suse.com>
- update to 0.5.9:
  * ethtool: fix module setup
  * ethtool: initial support <https://github.com/svinota/pyroute2/pull/675>
  * tc: multimatch support <https://github.com/svinota/pyroute2/pull/674>
  * tc: meta support <https://github.com/svinota/pyroute2/pull/671>
  * tc: cake: add stats_app decoder <https://github.com/svinota/pyroute2/pull/662>
  * conntrack: filter <https://github.com/svinota/pyroute2/pull/660>
  * ndb.objects.interface: reload after setns
  * ndb.objects.route: create() dst syntax
  * ndb.objects.route: 'default' syntax
  * wireguard: basic testing
* Sat Feb  8 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.5.7:
  * ndb.objects.netns: prototype
  * ndb: netns management
  * ndb: netns sources autoconnect (disabled by default)
  * wireguard: basic support
  * netns: fix FD leakage
  * <https://github.com/svinota/pyroute2/issues/623>
  * cli: Python3 fixes
  * iproute: support `route('append', ...)`
  * ipdb: fix routes cleanup on link down
  * <https://github.com/svinota/pyroute2/issues/620>
  * wiset: support "mark" ipset type
* Mon Jun  3 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.5.6:
  * ndb.objects.route: multipath routes
  * ndb.objects.rule: basic support
  * ndb.objects.interface: veth fixed
  * ndb.source: fix source restart
  * ndb.log: logging setup
* Fri Apr 12 2019 pgajdos@suse.com
- version update to 0.5.5
  * nftables: rules expressions
  * <https://github.com/svinota/pyroute2/pull/592>
  * netns: ns_pids
  * <https://github.com/svinota/pyroute2/pull/593>
  * ndb: wait() method
  * ndb: add extra logging, log state transitions
  * ndb: nested views, e.g. `ndb.interfaces['br0'].ports
  * cli: port pyroute2-cli to use NDB instead of IPDB
  * iproute: basic Windows support (proof of concept only)
  * remote: support mitogen proxy chains, support remote netns
* Mon Mar  4 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.5.4:
  * iproute: basic SR-IOV support, virtual functions setup
  * ipdb: shutdown logging fixed
  * ipset: fix regression
  * netns: pushns() / popns() / dropns() calls
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Mon Nov 12 2018 James Oakley <jfunk@funktronics.ca>
- update to 0.5.3:
  * bsd: parser improvements
  * ndb: PostgreSQL support
  * ndb: transactions commit/rollback
  * ndb: dependencies rollback
  * ipdb: IPv6 routes fix
  * <https://github.com/svinota/pyroute2/issues/543>
  * tcmsg: ematch support
  * tcmsg: flow filter
  * tcmsg: stats2 support improvements
  * ifinfmsg: GRE i/oflags, i/okey format fixed
  * <https://github.com/svinota/pyroute2/issues/531>
  * cli/ss2: improvements, tests
  * nlsocket: fix work on kernels < 3.2
  * <https://github.com/svinota/pyroute2/issues/526>
- changes from 0.5.2
  * ndb: read-only DB prototype
  * remote: support communication via stdio
  * general: fix async keyword -- Python 3.7 compatibility
  * <https://github.com/svinota/pyroute2/issues/467>
  * <https://bugzilla.redhat.com/show_bug.cgi?id=1583800>
  * iproute: support monitoring on BSD systems via PF_ROUTE
  * rtnl: support for SQL schema in message classes
  * nl80211: improvements
  * <https://github.com/svinota/pyroute2/issues/512>
  * <https://github.com/svinota/pyroute2/issues/514>
  * <https://github.com/svinota/pyroute2/issues/515>
  * netlink: support generators
- changes from 0.5.1
  * ipdb: #310 -- route keying fix
  * ipdb: #483, #484 -- callback internals change
  * ipdb: #499 -- eventloop interface
  * ipdb: #500 -- fix non-default :: routes
  * netns: #448 -- API change: setns() doesn't remove FD
  * netns: #504 -- fix resource leakage
  * bsd: initial commits
- changes from 0.5.0
  * ACHTUNG: ipdb commit logic is changed
  * ipdb: do not drop failed transactions
  * ipdb: #388 -- normalize IPv6 addresses
  * ipdb: #391 -- support both IPv4 and IPv6 default routes
  * ipdb: #392 -- fix MPLS route key reference
  * ipdb: #394 -- correctly work with route priorities
  * ipdb: #408 -- fix IPv6 routes in tables >= 256
  * ipdb: #416 -- fix VRF interfaces creation
  * ipset: multiple improvements
  * tuntap: #469 -- support s390x arch
  * nlsocket: #443 -- fix socket methods resolve order for Python2
  * netns: non-destructive `netns.create()`
* Tue Sep 19 2017 tbechtold@suse.com
- update to 0.4.21:
  * ipdb: #416 -- workaround for the vrf_table issue
  * ipdb: #392 -- fix MPLS route key reference
  * ipdb: #408 -- fix IPv6 routes in tables >= 256
  * ipdb: use tos as a route key
* Fri Aug 25 2017 tbechtold@suse.com
- update to 0.4.19:
  * ipdb: global methods `review()`, `drop()`, `dump()`, `load()`
  * ipdb: support VLAN protocol (802.1q, 802.1ad)
  * ipdb: initial support for IPv6 rules
  * ipdb: #388 -- normalize IPv6 addresses
  * ipdb: #391 -- support both IPv4 and IPv6 default routes
  * ipdb: #394 -- correctly work with route priorities
  * netns: non-destructive `netns.create()`
* Fri Aug 25 2017 tbechtold@suse.com
- update to 0.4.18:
  * ipdb: #379 [critical] -- routes in global commits
  * ipdb: #380 -- global commit with disabled plugins
  * ipdb: #381 -- exceptions fixed
  * ipdb: #382 -- manage dependent routes during interface commits
  * ipdb: #384 -- global `review()`
  * ipdb: #385 -- global `drop()`
  * netns: #383 -- support ppc64
  * general: public API refactored (same signatures; to be documented)
* Mon Jul 10 2017 tbechtold@suse.com
- update to 0.4.17:
  * req: #374 [critical] -- mode nla init
  * iproute: #378 [critical] -- fix `flush_routes()` to respect filters
  * ifinfmsg: #376 -- fix data plugins API to support pyinstaller
  * ipdb: race fixed: remove port/bridge
  * ipdb: #280 -- race fixed: port/bridge
  * ipdb: #302 -- ipaddr views: [ifname].ipaddr.ipv4, [ifname]ipaddr.ipv6
  * ipdb: #357 -- allow bridge timings to have some delta
  * ipdb: #338 -- allow to fix interface objects from failed `create()`
  * rtnl: #336 -- fix vlan flags
  * iproute: #342 -- the match method takes any callable
  * nlsocket: #367 -- increase default SO_SNDBUF
  * ifinfmsg: support tuntap on armv6l, armv7l platforms
- convert to singlespec
* Tue Jun 13 2017 dmueller@suse.com
- update to 0.4.15:
  * req: #365 -- full and short nla notation fixed, critical
  * iproute: #364 -- new method, `brport()`
  * ipdb: -- support bridge port options
  * event: new genl protocols set: VFS_DQUOT, acpi_event, thermal_event
  * ipdb: #310 -- fixed priority change on routes
  * ipdb: #349 -- fix setting ifalias on interfaces
  * ipdb: #353 -- mitigate kernel oops during bridge creation
  * ipdb: #354 -- allow to explicitly choose plugins to load
  * ipdb: #359 -- provide read-only context managers
  * rtnl: #336 -- vlan flags support
  * rtnl: #352 -- support interface type plugins
  * tc: #344 -- mirred action
  * tc: #346 -- connmark action
  * netlink: #358 -- memory optimization
  * config: #360 -- generic asyncio config
  * iproute: #362 -- allow to change or replace a qdisc
  * ipset: full rework of the IPSET_ATTR_DATA and IPSET_ATTR_ADT
    ACHTUNG: this commit may break API compatibility
  * ipset: hash:mac support
  * ipset: list:set support
  * ipdb: throw EEXIST when creates VLAN/VXLAN devs with same ID, but
    under different names
  * tests: #329 -- include unit tests into the bundle
  * legal: E/// logo removed
* Tue Jan 10 2017 dmueller@suse.com
- update to 0.4.12:
  * ipdb: #314 -- let users choose RTNL groups IPDB listens to
  * ipdb: #321 -- isolate `net_ns_.*` setup in a separate code block
  * ipdb: #322 -- IPv6 updates on interfaces in DOWN state
  * ifinfmsg: allow absolute/relative paths in the net_ns_fd NLA
  * ipset: #323 -- support setting counters on ipset add
  * ipset: `headers()` command
  * ipset: revisions
  * ipset: #326 -- mark types
* Mon Nov 21 2016 glin@suse.com
- Update to 0.4.11
  + rtnl: #284 -- support vlan_flags
  + ipdb: #288 -- do not inore link-local addresses
  + ipdb: #300 -- sort ip addresses
  + ipdb: #306 -- support net_ns_pid
  + ipdb: #307 -- fix IPv6 routes management
  + ipdb: #311 -- vlan interfaces address loading
  + iprsocket: #305 -- support NETLINK_LISTEN_ALL_NSID
  + devlink: fix fd leak on broken init
  + sock_diag: initial NETLINK_SOCK_DIAG support
  + rtnl: fix critical fd leak in the compat code
  + rtnl: compat proxying fix
  + rtnl: compat code is back
  + netns: custom netns path support
  + ipset: multiple improvements
* Tue Nov 15 2016 dmueller@suse.com
- update to 0.4.6:
  * ipdb: #278 -- fix initial ports mapping
  * ipset: #277 -- fix ADT attributes parsing
  * nl80211: #274, #275, #276 -- BSS-related fixes
* Mon Aug  8 2016 glin@suse.com
- Update Source url to pass the check in openSUSE:Factory
* Mon Aug  8 2016 glin@suse.com
- Update to 0.4.5
  + ifinfmsg: GTP interfaces support
  + generic: devlink protocol support
  + generic: code cleanup
  + iproute: #262 -- `get_vlans()` fix
  + iproute: default mask 32 for IPv4 in `addr()`
  + rtmsg: #260 -- RTA_FLOW support
  + ipdb: #259 -- critical `Interface` class fix
  + benchmark: initial release
  + ipdb: event modules
  + ipdb: on-demand views
  + ipdb: rules management
  + ipdb: bridge controls
  + ipdb: #258 -- important Python compatibility fixes
  + netns: #257 -- pipe leak fix
  + netlink: support pickling for nlmsg
  + netlink: no buffer copying in the parser
  + netlink: parse NLA on demand
  + ipdb: #244 -- lwtunnel multipath fixes
  + iproute: #235 -- route types
  + docs updated
* Sun May  8 2016 michael@stroeder.com
- Update to 0.4.0
* Fri Dec 11 2015 glin@suse.com
- Update to 0.3.15
* Fri Nov  6 2015 glin@suse.com
- initial import 0.3.14
